package
Version:
v0.0.0-...-4064bea
Opens a new window with list of versions in this module.
Published: Jan 17, 2024
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package testgoinputs is a testing package for bast.
Foo defines an interface to foo.
type Reee struct {
Tarded string `json:"-" db:"tarded"`
}
Reee defines a struct.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.