list

package
v0.0.0-...-4064bea Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package list implements boil's list command.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(config *Config) (err error)

Run executes the List command configured by config. If an error occurs it is returned and the operation may be considered failed.

Types

type Config

type Config struct {
	// Prefix is the path prefix at which to start listing.
	Prefix string
	// Config is the loaded program configuration.
	Config *boil.Config
}

Config is the List command configuration.

Jump to