snap

package
v0.0.0-...-4064bea Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 17, 2024 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package snap implements boil's snap command.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(config *Config) (err error)

Run executes the Snap command configured by config. If an error occurs it is returned and the operation may be considered failed.

Types

type Config

type Config struct {
	// TemplatePath is the path under which the Template will be stored
	// relative to the loaded repository root.
	TemplatePath string

	// SourcePath is an optional path to the source directory or file.
	// If ommitted a snapshot of the current directory is created.
	SourcePath string

	// Wizard specifies if a template wizard should be used.
	Wizard bool

	// Force overwriting template if it already exists.
	Overwrite bool

	// Config is the loaded program configuration.
	Config *boil.Config
}

Config is the Snap command configuration.

Jump to