Documentation
¶
Overview ¶
Package snap implements boil's snap command.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
// TemplatePath is the path under which the Template will be stored
// relative to the loaded repository root.
TemplatePath string
// SourcePath is an optional path to the source directory or file.
// If ommitted a snapshot of the current directory is created.
SourcePath string
// Wizard specifies if a template wizard should be used.
Wizard bool
// Force overwriting template if it already exists.
Overwrite bool
// Config is the loaded program configuration.
Config *boil.Config
}
Config is the Snap command configuration.
Click to show internal directories.
Click to hide internal directories.